@@ -15,7 +15,7 @@ import sys
 from datetime import datetime
 from typing import IO, Dict, List, Union
 
-from .literals import FilterNameStringType, StatusType
+from .literals import FilterNameStringTypeType, StatusTypeType
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -122,7 +122,7 @@ DescribeSecretResponseTypeDef = TypedDict(
 FilterTypeDef = TypedDict(
     "FilterTypeDef",
     {
-        "Key": FilterNameStringType,
+        "Key": FilterNameStringTypeType,
         "Values": List[str],
     },
     total=False,
@@ -242,7 +242,7 @@ ReplicationStatusTypeTypeDef = TypedDict(
     {
         "Region": str,
         "KmsKeyId": str,
-        "Status": StatusType,
+        "Status": StatusTypeType,
         "StatusMessage": str,
         "LastAccessedDate": datetime,
     },
